/* vim: set foldmethod=marker : */
#ifndef CC2500_H
#define CC2500_H

#include <stdint.h>

/* Command strobes *//*{{{*/
#define CC2500_SRES 			0x30 
#define CC2500_SFSTXON 			0x31 
#define CC2500_SXOFF 			0x32 
#define CC2500_SCAL 			0x33 
#define CC2500_SRX 				0x34 
#define CC2500_STX 				0x35 
#define CC2500_SIDLE 			0x36 
#define CC2500_SWOR 			0x38 
#define CC2500_SPWD 			0x39 
#define CC2500_SFRX 			0x3A 
#define CC2500_SFTX 			0x3B 
#define CC2500_SWORRST 			0x3C 
#define CC2500_SNOP 			0x3D
/*}}}*/

/*Configuration registers */ /*{{{*/
#define CC2500_IOCFG2 			0x00
#define CC2500_IOCFG1 			0x01 
#define CC2500_IOCFG0 			0x02 
#define CC2500_FIFOTHR 			0x03 
#define CC2500_SYNC1	 		0x04 
#define CC2500_SYNC0 			0x05 
#define CC2500_PKTLEN 			0x06 
#define CC2500_PKTCTRL1 		0x07 
#define CC2500_PKTCTRL0 		0x08 
#define CC2500_ADDR 			0x09 
#define CC2500_CHANNR 			0x0A 
#define CC2500_FSCTRL1 			0x0B 
#define CC2500_FSCTRL0 			0x0C 
#define CC2500_FREQ2 			0x0D 
#define CC2500_FREQ1	 		0x0E 
#define CC2500_FREQ0	 		0x0F 
#define CC2500_MDMCFG4 			0x10 
#define CC2500_MDMCFG3 			0x11 
#define CC2500_MDMCFG2 			0x12 
#define CC2500_MDMCFG1 			0x13 
#define CC2500_MDMCFG0 			0x14 
#define CC2500_DEVIATN 			0x15 
#define CC2500_MCSM2	 		0x16 
#define CC2500_MCSM1 			0x17 
#define CC2500_MCSM0 			0x18 
#define CC2500_FOCCFG 			0x19 
#define CC2500_BSCFG 			0x1A 
#define CC2500_AGCTRL2 			0x1B 
#define CC2500_AGCTRL1 			0x1C 
#define CC2500_AGCTRL0 			0x1D 
#define CC2500_WOREVT1 			0x1E 
#define CC2500_WOREVT0 			0x1F 
#define CC2500_WORCTRL 			0x20 
#define CC2500_FREND1 			0x21 
#define CC2500_FREND0 			0x22 
#define CC2500_FSCAL3 			0x23 
#define CC2500_FSCAL2 			0x24 
#define CC2500_FSCAL1 			0x25 
#define CC2500_FSCAL0 			0x26 
#define CC2500_RCCTRL1 			0x27 
#define CC2500_RCCTRL0 			0x28 
#define CC2500_FSTEST 			0x29 
#define CC2500_PTEST 			0x2A 
#define CC2500_AGCTEST 			0x2B 
#define CC2500_TEST2 			0x2C 
#define CC2500_TEST1 			0x2D 
#define CC2500_TEST0 			0x2E 

#define CC2500_PARTNUM 			0x30 
#define CC2500_VERSION 			0x31 
#define CC2500_FREQEST 			0x32 
#define CC2500_LQI 				0x33 
#define CC2500_RSSI 			0x34 
#define CC2500_MARCSTATE 		0x35 
#define CC2500_WORTIME1 		0x36 
#define CC2500_WORTIME0 		0x37 
#define CC2500_PKTSTATUS 		0x38 
#define CC2500_VCO_VC_DAC 		0x39 
#define CC2500_TXBYTES 			0x3A 
#define CC2500_RXBYTES 			0x3B 
#define CC2500_RCCTRL1_STATUS	0x3C 
#define CC2500_RCCTRL0_STATUS	0x3D
#define CC2500_PATABLE			0x3E
#define CC2500_RX_FIFO			0x3F
#define CC2500_TX_FIFO			0x3F
/*}}}*/

typedef void (*cc2500_isr)(void);


#define CC2500_STATUS_CHIP_RDYn_BM             0x80
#define CC2500_STATUS_STATE_BM                 0x70
#define CC2500_STATUS_FIFO_BYTES_AVAILABLE_BM  0x0F

// Chip states
#define CC2500_STATE_IDLE                      0x00
#define CC2500_STATE_RX                        0x10
#define CC2500_STATE_TX                        0x20
#define CC2500_STATE_FSTXON                    0x30
#define CC2500_STATE_CALIBRATE                 0x40
#define CC2500_STATE_SETTLING                  0x50
#define CC2500_STATE_RX_OVERFLOW               0x60
#define CC2500_STATE_TX_UNDERFLOW              0x70

#define CC2500_LQI_CRC_OK_BM                   0x80
#define CC2500_LQI_EST_BM                      0x7F

uint8_t cc2500_status(uint8_t tx);
uint8_t cc2500_read(uint8_t address);
void cc2500_read_burst(uint8_t address, uint8_t n, uint8_t *buf);
void cc2500_write(uint8_t address, uint8_t data);
void cc2500_write_burst(uint8_t address, uint8_t n, uint8_t *buf);
void cc2500_por(void);
void cc2500_init(void);
void cc2500_command(uint8_t command);

#endif
