#include <avr/io.h>
#include <avr/interrupt.h>
#include <inttypes.h>
#include <stdlib.h>
#include <stdio.h>

#include <util/delay.h>
#include "cc2500.h"


static int uart_putchar(char c, FILE *stream);

static FILE mystdout = FDEV_SETUP_STREAM(uart_putchar, NULL,
										 _FDEV_SETUP_WRITE);


static int uart_putchar(char c, FILE *stream)
{
	while (!(UCSRA & _BV(UDRE)));
	UDR = c;
	return 0;
}

int main(void)
{

	/*  SPI */
  	DDRB |= 0xB0;
	PORTB |= _BV(6) | _BV(4);
	SPCR = _BV(SPE) | _BV(MSTR);

	UCSRB = _BV(TXEN);
	UCSRC = _BV(UMSEL) | (2 << UCSZ0);

	UBRRH = 0;
	UBRRL = 25;

	stdout = &mystdout;

	/*     */
	cc2500_por();
	/*   ,  SmartRF Studio */
	cc2500_init();

	cc2500_write(CC2500_MCSM0,	0x18); // Calibration from IDLE to TX/RX
	cc2500_write(CC2500_MCSM1,	0x00); // No CCA, IDLE after TX and RX
	cc2500_write(CC2500_PKTCTRL0, 0x45); // Enable data whitening and CRC
	cc2500_write(CC2500_PKTCTRL1, 0x04); // Enable append mode

	uint8_t data[3];

	uint8_t pcktnum = 0;
	while (1) {
		uint8_t status;
		uint8_t len;

		/*     (  - ,    )*/
		cc2500_command(CC2500_SIDLE);
		/*    -     -  ""  */
		cc2500_command(CC2500_SFRX);
		/*     */
		cc2500_command(CC2500_SRX);

		/*          */
		do {
		   status = cc2500_status(0) & 0xF0;
		   _delay_ms(2);
		} while (status != 0 && status != 0x60);

		/*  status != 0 -        -
		 *     */
		if (status != 0) {
			continue;
		}

		/*     -   */
		cc2500_read_burst(CC2500_RX_FIFO, 1, &len);

		/*    3 */
		if (len != 3) {
			continue;
		}

		/*   */
		cc2500_read_burst(CC2500_RX_FIFO, len, data);

		/*    append mode,   
		 *      ,  
		 * RSSI    CRC */

		/* RSSI  */
		cc2500_read_burst(CC2500_RX_FIFO, 1, &status);

		/*     CRC */
		cc2500_read_burst(CC2500_RX_FIFO, 1, &status);

		if (!(status & CC2500_LQI_CRC_OK_BM)) {
			/*  CRC */
			continue;
		}
		
		/*     -  */
		if (data[0] == pcktnum) {
			continue;
		}
		pcktnum = data[0];

		if (data[2] != 0xFF) {
			/*        */
			/*       UART */
			printf("Command : %d\n", data[1]);
			printf("Distance : %d\n", data[2]);
		}

	}
}

